# Method for computing Concordance Indexes refactored from ELECTRE III method as it is also utilized by ELECTRE 1S method
# parameters:
#   - PM - performance matrix
#   - P  - preference threshold
#   - Q  - indifference threshold
#   - w  - weights
Electre3_ConcordanceIndex <- function(PM, P, Q, w){
  nalt <- nrow(PM)
  ncri <- ncol(PM)
  alt  <- rownames(PM)
  cm   <- matrix(data = 0, nrow = nalt, ncol = nalt)  #concordance matrix
  cjw  <- list()   #temp variable holds cj (concordance matrix for the criteria)
  for(k in 1:ncri){      #index for criteria
    c  <- matrix(data = 0, nrow = nalt, ncol = nalt)  #temp var for cj
    colnames(c) <- alt
    rownames(c) <- alt
    for(i in 1:nalt){    #index for a
      for(j in 1:nalt){  #index for b
        #concordance matrix
        #represents percentage of weights of criteria that concord with the proposition 'a outranks b'
        # C(a,b) = 1/W * SUM(wj*cj(a,b))
        # W = SUM(wj)
        # cj(a,b) = 1 if PMj(a) + Qj(a) >= PMj(b)
        # cj(a,b) = 0 if PMj(a) + Pj(a) < PMj(b)
        # else c(a,b) = (PMj(a) - PMj(b) + Pj(a)) / (Pj(a) - Qj(a))
        if(PM[i,k] + Q[k] >= PM[j,k]){
          c[i,j] <- 1
        }else if(PM[i,k] + P[k] < PM[j,k]){
          c[i,j] <- 0
        }else{
          if(P[i] - Q[k] != 0){
            c[i,j] <- (PM[i,k] - PM[j,k] + P[k])/(P[k] - Q[k])
          }else{
            c[i,j] <- 1
          }
        }
      }
    }
    cjw[[k]] <- c * w[k]
  }
  cm <- Reduce('+', cjw)/sum(w) #cm = sum(cjw)/sum(w)
  colnames(cm) <- alt
  rownames(cm) <- alt
  out <- list(
    ConcordanceMatrix = cm
  )
  return(out)
}
