# PROMETHEE I function
#
# parameters
#   PM - performance matrix
#   preferenceFunction - vector of preference functions types to derive preference when comparing PM
#   w - weights
#   minmax - min/max value or vector of mixed values for criteria orientation
#   indifferenceTreshold list of indifference thresholds
#   prefferenceThreshold list of prefference thresholds
#   intermediateThreshold lish of intermediate thresholds for Gaussian function type
PROMETHEE_I <- function(PM, preferenceFunction, w, minmax = 'max',
                        indifferenceTreshold = NULL, prefferenceThreshold = NULL,
                      intermediateThreshold = NULL){
  #params consistency check centralized in generalized PROMETHEE function
  nalt <- nrow(PM)  #no. of alternatives
  alt  <- rownames(PM) #list of alternatives
  #here is only minmax evaluation
  PM <- util_pm_minmax(PM, minmax) #validate minmax and invert scales if neccessary
  #end of parameter consistency check

  flow <- PROMETHEE(PM, preferenceFunction, w, indifferenceTreshold, prefferenceThreshold, intermediateThreshold)
  pf <- flow$positiveFlow
  nf <- flow$negativeFlow

  #establish preference system
  pref <- matrix(data = 0, nrow = nalt, ncol = nalt)
  for(i in 1:nalt){
    for(j in 1:nalt){
        if((pf[i] > pf[j] && nf[i] < nf[j]) ||
           (pf[i] == pf[j] && nf[i] < nf[j]) ||
           (pf[i] > pf[j] && nf[i] == nf[j])) { #aPb (a preffered to b)
          pref[i,j] <- 'P'
        }else if((pf[i] == pf[j] && nf[i] == nf[j])){ #aIb (a indifferent to b)
          pref[i,j] <- 'I'
        }else if((pf[i] > pf[j] && nf[i] > nf[j]) ||
                 (pf[i] < pf[j] && nf[i] < nf[j])){ #aRb (a incomparable to b)
          pref[i,j] <- 'R'
        }
    }
  }
  rownames(pref) <- alt
  colnames(pref) <- alt

  out <- list(
    positiveFlow = pf,
    negativeFlow = nf,
    preferenceDegree = flow$preferenceDegree,
    preferenceDegreeUnw = flow$preferenceDegreeUnw,
    pairweiseComparison = flow$pairweiseComparison,
    preferenceMatrix = pref
  )
  return(out)
}
