\name{Electre_1}
\alias{Electre_1}
\title{Electre_1 : ELECTRE I method used to solve multiple criteria decision making}
\description{The acronym ELECTRE stands for: ELimination Et Choix Traduisant la REalite (ELimination and Choice Expressing REality).ELECTRE I method is then designed to rank reliability design scheme in order of decision maker preference.This method is based on the concept of concordance and discordance.

ELECTRE I does not provide rank, but allows the user to identify so called kernel of the decision - the alternatives, which cannot be eleminated from decision making as obviously inefficient, thus simplifying the decision making problem.

Technically the function implements approach authored by M. Balamurali in pyDecisions (in Python) and reimplements it in R.
}
\usage{
Electre_1(PM,
			w,
			minmaxcriteria,
			concordance_threshold = 1,
			discordance_threshold = 0)
}

\arguments{
  \item{PM}{Matrix or data frame containing the performance table. Each row corresponds to an alternative, and each column to a criterion. only numeric values expercted. Rows and columns are expected to be named.}
  \item{w}{vector containing the weights of the criteria.}
  \item{minmaxcriteria}{criteriaMinMax Vector containing the preference direction on each of the criteria. "min" (resp."max") indicates that the criterion has to be minimized (maximized).}
  \item{concordance_threshold}{parameter defining concordance threshold . The default value is 1. The user can set a new value between 0 and 1}
  \item{discordance_threshold}{parameter defining discordance threshold . The default value is 0. The user can set a new value between 0 and 1.}
}

\value{
	The function returns a list structured as follows :
	\item{PerformanceMatrix}{A matrix containing the performance table. Each row corresponds to an alternative, and each column to a criterion}
	\item{ConcordanceMatrix}{Concordance matrix is one of two working relations (concordance and discordance) which are subsequently used to construct the final dominance relation. For an outranking aSb to be validated, a sufficient majority of criteria should be in favor of this assertion.}
	\item{DiscordanceMatrix}{Discordance matrix is one of two working relations (concordance and discordance) which are subsequently used to construct the final dominance relation. The concept of discordance is complementary to the one of (concordance and represents the discomfort experienced in the choosing of alternative a above alternative b}
	\item{PreferenceMatrix}{A matrix with computed preferences for the alternatives. Represents domination relation between the alternatives. Provides value 1 where for relation between alternatives where such domination exists}
	\item{Kernel}{Kernel consist of subset of non-dominated alternatives}
  \item{Dominated}{Identified clearly dominated alternatives.}
  \item{GraphResult}{Visualization of the preference matrix using network graph. A -> B means, that A outranks B.}
}

\references{
Balamurali, M.: pyDecisions - A Python Library of management decision making techniques. Avilable on-line from \url{https://github.com/Valdecy/pyDecisions}

Rogers, Martin and Myastre, Lucien-Yves. ELECTRE and Decision Support: Methods and Applications in Engineering and Infrastructure investment. Springer 2000, 208 p., ISBN 978-1-4757-5057-7

Prombo, M. Package OutrankingTools, CRAN: 2015, available from: \url{https://cran.r-project.org/web/packages/OutrankingTools/}
}

\author{Pavel Šenovský \email{pavel.senovsky@vsb.cz}}

\examples{
PM <- cbind(
  c(103000,101300,156400,267400,49900,103600,103000,170100,279700,405000),
  c(171.3,205.3,221.7,230.7,122.6,205.1,178.0,226.0,233.8,265.0),
  c(7.65,7.90,7.90,10.50,8.30,8.20,7.20,9.10,10.90,10.30),
  c(352,203,391,419,120,265,419,419,359,265),
  c(11.6,8.4,8.4,8.6,23.7,8.1,11.4,8.1,7.8,6.0),
  c(88.0,78.3,81.5,64.7,74.1,81.7,77.6,74.7,75.5,74.7),
  c(69.7,73.4,69.0,65.6,76.4,73.6,66.2,71.7,70.9,72.0))
rownames(PM) <- c("CBX16","P205G","P405M","P605S","R4GTL",
  "RCLIO","R21TS","R21TU","R25BA","ALPIN")
colnames(PM) <- c("Prix","Vmax","C120","Coff","Acce","Frei","Brui")
minmaxcriteria <-c("min","max","min","max","min","min","min")
w <- c(0.3,0.1,0.3,0.2,0.1,0.2,0.1)
M <- Electre_1(PM, w, minmaxcriteria,
  concordance_threshold = 0.8,
  discordance_threshold = 0.1)
}

\keyword{ ELECTRE I }
\keyword{ concordance matrix }
\keyword{ discordane matrix }
