\name{Electre_1S}
\alias{Electre_1S}
\title{Electre_1S : ELECTRE 1S method used to solve multiple criteria decision making}
\description{
Method for supporting multicriteria decision making used to identify so called kernel of solution as set of alternatives which are not dominated by any other alternative. Dominated alternatives can be ommited from decision making as they clearly represent sub-optimal solution for the problem.

Method does not provide ranking.

Computationally the method can be seen as a hybrid of ELECTRE III and I methods. From ELECTRE III it takes concordance matrix computation as it works with fuzzy defined preference (P), indifference (Q) and veto (V) thresholds. From ELECTRE I method it takes procedure to identify kernel of the solution.
}
\usage{
Electre_1S(PM, w, Q, P, V, minmaxcriteria = 'max', lambda = 0.5)
}

\arguments{
  \item{PM}{Matrix or data frame containing the performance table. Each row corresponds to an alternative, and each column to a criterion. only numeric values expercted. Rows and columns are expected to be named.}
  \item{w}{vector containing the weights of the criteria.}
  \item{Q}{vector of indifference thresholds}
  \item{P}{vector of preference thresholds}
  \item{V}{vector of veto thresholds}
  \item{minmaxcriteria}{criteriaMinMax Vector containing the preference direction on each of the criteria. "min" (resp."max") indicates that the criterion has to be minimized (maximized).}
  \item{lambda}{parameter defining concordance threshold. The default value is 0.5, but the value can be in interval <0.5;1>.}
}

\value{
	The function returns a list structured as follows :
	\item{PerformanceMatrix}{A matrix containing the performance table. Each row corresponds to an alternative, and each column to a criterion}
	\item{ConcordanceMatrix}{Concordance matrix is one of two working relations (concordance and discordance) which are subsequently used to construct the final dominance relation. For an outranking aSb to be validated, a sufficient majority of criteria should be in favor of this assertion.}
	\item{DiscordanceIndex}{Discordance matrix is one of two working relations (concordance and discordance) which are subsequently used to construct the final dominance relation. The concept of discordance is complementary to the one of (concordance and represents the discomfort experienced in the choosing of alternative a above alternative b}
	\item{CredibilityIndex}{basically preference matrix as computed by ELECTRE I method. Represents domination relation between the alternatives. Provides value 1 where for relation between alternatives where such domination exists}
	\item{Kernel}{Kernel consist of subset of non-dominated alternatives}
  \item{Dominated}{Identified clearly dominated alternatives.}
  \item{graph}{Visualization of the preference matrix using network graph. A -> B means, that A outranks B.}
}

\references{
Balamurali, M.: pyDecisions - A Python Library of management decision making techniques. Avilable on-line from \url{https://github.com/Valdecy/pyDecisions}

Rogers, Martin and Myastre, Lucien-Yves. ELECTRE and Decision Support: Methods and Applications in Engineering and Infrastructure investment. Springer 2000, 208 p., ISBN 978-1-4757-5057-7

Prombo, M. Package OutrankingTools, CRAN: 2015, available from: \url{https://cran.r-project.org/web/packages/OutrankingTools/}

Rogers, Martin and Myastre, Lucien-Yves. ELECTRE and Decision Support: Methods and Applications in Engineering and Infrastructure investment. Springer 2000, 208 p., ISBN 978-1-4757-5057-7
}

\author{Pavel Šenovský \email{pavel.senovsky@vsb.cz}}

\examples{
# the performance table
PM <- cbind(
  c(-14,129,-10,44,-14),
  c(90,100,50,90,100),
  c(0,0,0,0,0),
  c(40,0,10,5,20),
  c(100,0,100,20,40)
)
rownames(PM) <- c("Project1","Project2","Project3","Project4","Project5")
colnames(PM) <- c( "CR1","CR2","CR3","CR4","CR5")
minmaxcriteria <- 'max'
Q <- c(25,16,0,12,10) #Indifference thresholds
P <- c(50,24,1,24,20) #Preference thresholds
V <- c(100,60,2,48,90) #Veto thresholds
w <- c(1,1,1,1,1) #weights
Electre_1S(PM, w, Q, P, V, minmaxcriteria)
}
\keyword{ ELECTRE I }
\keyword{ ELECTRE III }
\keyword{ ELECTRE 1S }
\keyword{ concordance matrix }
\keyword{ discordane matrix }
\keyword{ kernel }
