\name{FuzzyVIKOR}
\alias{FuzzyVIKOR}
\title{FuzzyVIKOR : method used to solve multiple criteria decision making}
\description{The acronym VIKOR stands for: VlseKriterijumska Optimizacija I Kompromisno Resenje, in Serbian multicriteria optimization and compromise solution. The method has been especially designed to deal with problematic situations when the alternatives are characterized by non-commensurable and conflicting criteria, for which VIKOR provides compromise solution. Methodologically VIKOR is close to another method TOPSIS. Original VIKOR uses five steps to derive such compromise solution.

FuzzyVIKOR uses trapezoidal fuzzy number for computation purposes. Other then using fuzzy number for computation, the results are basically the same: S, R and Q, which can be used to compute compromise solution. Look in the VIKOR function description to better understand the computation proces (or the source code).

At present time FuzzyVIKOR function does not have implemented establishment of compromise solution.
}
\usage{
FuzzyVIKOR(PM, dictionaryPM, w, dictionaryW, alt)
}

\arguments{
  \item{PM}{performance matrix with n columns and no. criteria x no. of alternatives rows. I. e. with 3 criteria and 2 alternatives the rows are: 1: 1.cri-1.alt., 2: 1.cri.-2.alt, 3: 2.cri-1.alt, 4: 2.cri-2.alt, ...}
  \item{dictionaryPM}{dictionary of linguistic variables for criteria}
  \item{w}{weights (matrix of weights - decision makers in columns and criteria in rows)}
  \item{dictionaryW}{dictionary for wights (single matrix|dataframe)}
  \item{alt}{vector with names of the alternatives}
}

\value{
	The function returns a list structured as follows :
	\item{S}{list of alternatives using S-metric}
	\item{R}{list of alternatives using R-metric}
	\item{Q}{list of alternatives using Q-metric}
}

\references{
ALAOUI, Mohamed El. Fuzzy TOPSIS: Logic, Approaches, and Case Studies. Boca Raton: CRC Press, 2021. 216 s. ISBN 978-0-367-76748-8.

Papathanasiou, Jason, Ploskas, Nikolaos. Multiple Criteria Decision Aid Methods, Examples and Python Implementations. Springer, 173 p., ISBN 978-3-319-91648-4.
}

\author{Pavel Šenovský \email{pavel.senovsky@vsb.cz}}

\examples{
dictionaryW <- rbind(
  c(0, 0, 0.1, 0.2),
  c(0.1, 0.2, 0.2, 0.3),
  c(0.2, 0.3, 0.4, 0.5),
  c(0.4, 0.5, 0.5, 0.6),
  c(0.5, 0.6, 0.7, 0.8),
  c(0.7, 0.8, 0.8, 0.9),
  c(0.8, 0.9, 1, 1)
)
#V very, L low, M medium, H high
rownames(dictionaryW) <- c('VL', 'L', 'ML', 'M', 'MH', 'H', 'VH')
w <- rbind(
  c('H', 'VH', 'VH'),
  c('M', 'H', 'VH'),
  c('M', 'MH', 'ML'),
  c('H', 'VH', 'MH')
)
rownames(w) <- c('Investment cost', 'Employment needs', 'Social impact',
                 'Environmental impact')
dictionaryPM <- rbind(
  c(0, 0, 0.1, 0.2),
  c(0.1, 0.2, 0.2, 0.3),
  c(0.2, 0.3, 0.4, 0.5),
  c(0.4, 0.5, 0.5, 0.6),
  c(0.5, 0.6, 0.7, 0.8),
  c(0.7, 0.8, 0.8, 0.9),
  c(0.8, 0.9, 1, 1)
)
#V very, P poor, M medium, F fair, G good
rownames(dictionaryPM) <- c('VP', 'P', 'MP', 'F', 'MG', 'G', 'VG')
PM <- rbind(
  c('VG', 'G', 'MG'),
  c('MP', 'F', 'F'),
  c('MG', 'MP', 'F'),
  c('MG', 'MG', 'VG'),
  c('VP', 'P', 'G'),
  c('F', 'G', 'G'),
  c('F', 'MG', 'MG'),
  c('F', 'VG', 'G'),
  c('MG', 'MG', 'VG'),
  c('G', 'G', 'VG'),
  c('P', 'VP', 'MP'),
  c('F', 'MP', 'MG'),
  c('P', 'P', 'MP'),
  c('MG', 'VG', 'G'),
  c('MP', 'F', 'F'),
  c('MG', 'VG', 'G'),
  c('G', 'G', 'VG'),
  c('VG', 'MG', 'F'),
  c('G', 'VG', 'G'),
  c('MG', 'F', 'MP'),
  c('MP', 'P', 'P'),
  c('VP', 'F', 'P'),
  c('G', 'MG', 'MG'),
  c('P', 'MP', 'F')
)
alternatives <- c('site 1', 'site 2', 'site 3', 'site 4', 'site 5', 'site 6')
result <- FuzzyVIKOR(PM, dictionaryPM, w, dictionaryW, alternatives)
}
\keyword{ FuzzyVIKOR }
